# scrunch

Pythonic scripting library for cleaning data in Crunch.

[![Build Status](https://travis-ci.org/Crunch-io/scrunch.svg?branch=master)](https://travis-ci.org/Crunch-io/scrunch)

For more information see the [Overview](https://github.com/Crunch-io/scrunch/wiki/Overview) wiki page.
